---
title: 엔드유저의 Shopify 결제 경험
description: 실 고객의 Shopify 결제 화면을 설명합니다.
targetVersions:
  - v1
---

## 구매 플로우

1. 엔드유저는 고객사의 Shopify 스토어에서 상품을 장바구니에 추가하여 최종 구매페이지에 도달하게 됩니다.

(관련 이미지 첨부)

(관련 이미지 첨부)

(관련 이미지 첨부)

(관련 이미지 첨부)

2. 최종 체크아웃 페이지에 도달하면 결제가 PortOne Payment 로 진행된다는 안내문구를 확인할 수 있습니다.

(관련 이미지 첨부)

3. Pay now 를 클릭하면 유저는 PortOne 의 체크아웃 창으로 이동하게 되고
   Shopify 스토어에 설정된 Currency 와 PortOne(Global) 어드민에서 설정된 조건에 따라 결제수단이 노출되고 최종결제가 이루어집니다.

(관련 이미지 첨부)
